<?
    /*
     * File: util.php
     *
     * Description:
     * Contains basic utility functions use throughout the site.
     *
     * Creator: Chris Ryan <chris@greatbridge.com>
     * Created: 09/20/2000
     *
     * Change Log:
     *     Chris Ryan <chris@greatbridge.com> 09/20/2000
     *         - Initial file creation
     *     Chris Ryan <chris@greatbridge.com> 09/28/2000
     *         - Added sqlText() function
     *     Chris Ryan <chris@greatbridge.com> 10/17/2000
     *         - Added fixQuotes() function
     *         - Changed sqlText to call fixQuotes()
     *         - Added sqlDate() function
     *     Chris Ryan <chris@greatbridge.com> 10/24/2000
     *         - Added the use of pg_freeresult after completed queries
     *     Chris Ryan <chris@greatbridge.com> 10/25/2000
     *         - Modified the sqlDate function to do alot more error checking
     *           of the date values
     */


    /*
     * Function: RedirectTo($url)
     *
     * Description: Sends a redirection url and page
     */
    function RedirectTo($url) {
        header("Refresh:0;URL=$url");
        echo " ";
    }

    /*
     * Function: fixQuotes($text)
     *
     * Description: This function takes in a string and replaceses all
     * \' and \" with ' and " respectively and returns the new string.
     */
    function fixQuotes($text) {
        $text = str_replace("\\'","'",$text);
        $text = str_replace("\\\"","\"",$text);
        return $text;
    }

    /*
     * Function: sqlText($text)
     *
     * Description:
     *     Converts a string into an acceptable sql string. blank values are
     * returned as null otherwise they are quoted using single quotes (') and
     * all single quotes within the text are escaped out.
     */
    function sqlText($text) {
        if($text) {
            return "'" . str_replace("'","''",fixQuotes($text)) . "'";
        } else {
            return "null";
        }
    }

    /*
     * Function: sqlDate($date, $default = "")
     *
     * Description:
     *     Convert a string into an exceptable sql date value.
     * if default is empty then this function will return null,
     * otherwise it will return the default value, unless default
     * is equal to "now" then it will return the current value of
     * now on the database.
     */
    function sqlDate($date, $default = "") {
        global $conn;
        if(empty($date)) {
            if(empty($default)) {
                return "null";
            } else if($default == "now") {
                $query = "select now()";
                $res   = pg_exec($conn,$query);
                $ret = "'" . pg_result($res,0,0) . "'";
                pg_freeresult($res);
                return $ret;
            } else {
                return sqlDate($default);
            }
        } else {
            # should do something better than just quote the value
            # passed in but not sure what is better?!?
            $parts = split('[/.-]',$date);
            if(count($parts) < 3) {
                $dt = getdate();
                if(substr($date,-1) == "'")
                    $date = substr($date,0,-1) . "/" . $dt["year"] . "'";
                else
                    $date .= "/" . $dt["year"];
            }
            return (substr($date,0,1)!="'"?"'":"") . $date . (substr($date,-1)!="'"?"'":"");
        }
    }
 ?>
