/*
 * File: new_tables.sql
 *
 * Description:
 *     Contains the tables used for news.greatbridge.com, the marketing
 *     groups site
 *
 * Creator: Allen McGrath
 * Created: 09/29/2000
 *
 * Change log:
 *     Chris Ryan <chris@greatbridge.com> 11/01/2000
 *         - Changed the order in which the tables where created cause
 *           of the references dependency.
 */

/* 
 * Table: mktg_code
 * 
 * Description:
 * store all valid mktg codes marketing team comes up with
 * 
 *  Field Description:
 * mktg_code code entered by marketing team
 * create_date 	date record created
 * active  t= yes f=no
 * description description fo the code
*/
 CREATE TABLE mktg_code 
(
     mktg_code		varchar(20) not null unique,
     create_date	date default now(),
     active		bool default 't',
     description 	text,
     primary key (mktg_code)
);

/*
 * Table: news_access 
 *
 * Description:
 * stores all pages/files accessed on site by users
 * 
 * Field Description:
 * access_id		inserted via script (md5 generated).
 * create_date		date record was created.
 * mktg_code		code created via admin tool, found in mktg_code
 */
 CREATE TABLE news_access 
(
    access_id	  	VARCHAR(32) NOT NULL,
    create_date		DATE DEFAULT NOW(),
    mktg_code		varchar(25) not null references mktg_code,
    action		varchar(20),
    primary key (access_id,action)
);

